@@ -1,3 +1,9 @@
+#!/usr/bin/env python
+# coding: utf-8
+
+# Copyright (c) Saga Inc.
+# Distributed under the terms of the GPL License.
+
 """
 Mito currently collects logs on basic user interactions with the app, 
 so that we can improve the tool.
@@ -18,43 +24,49 @@ Our general approach to logging can be understood as:
    This appears to be good practice, as it allows us to associate what actions are taken
    with their result very effectively!
 """
-from typing import Any, Dict, List, TYPE_CHECKING
-from mitosheet.user.schemas import UJ_MITOSHEET_TELEMETRY
 import platform
-import sys
 import subprocess
+import sys
+import time
+from typing import Any, Dict, List
 
 from mitosheet.parser import parse_formula
-
-# To avoid circular imports
-if TYPE_CHECKING:
-    from mitosheet.steps_manager import StepsManager
-else: 
-    StepsManager = Any
-
+from mitosheet.types import StepsManagerType
+from mitosheet.user.schemas import UJ_MITOSHEET_TELEMETRY
+from mitosheet.user.location import get_location, is_docker
 
 try:
     from jupyterlab import __version__ as jupyterlab_version
 except:
     jupyterlab_version = 'No JupyterLab'
+try:
+    from notebook import __version__ as notebook_version
+except:
+    notebook_version = 'No notebook'
 
 import analytics
+
 # Write key taken from segement.com
 analytics.write_key = '6I7ptc5wcIGC4WZ0N1t0NXvvAbjRGUgX' 
 
-from mitosheet.user import (
-    UJ_INTENDED_BEHAVIOR, UJ_STATIC_USER_ID, UJ_USER_SALT, UJ_USER_EMAIL, 
-    UJ_FEEDBACKS, 
-)
-from mitosheet.user import get_user_field, is_local_deployment, is_running_test, is_local_deployment
-from mitosheet._version import __version__
+from mitosheet._version import __version__, package_name
 from mitosheet.errors import MitoError, get_recent_traceback_as_list
+from mitosheet.user import (UJ_FEEDBACKS, UJ_INTENDED_BEHAVIOR,
+                            UJ_STATIC_USER_ID, UJ_USER_EMAIL, UJ_USER_SALT,
+                            get_user_field, is_local_deployment,
+                            is_running_test)
+
 
 def telemetry_turned_on() -> bool:
     """
     Helper function that tells if you if logging is turned on or
     turned off on the entire Mito instance
     """
+    # If the current package is mitosheet-private, then we don't log anything,
+    # ever, under any circumstances - this is a custom distribution for a client
+    if package_name == 'mitosheet-private':
+        return False
+
     telemetry = get_user_field(UJ_MITOSHEET_TELEMETRY) 
     return telemetry if telemetry is not None else False
 
@@ -89,7 +101,7 @@ def anonymize_word(word: Any) -> str:
     return valid_words[index_one] + valid_words[index_two] + valid_words[index_three]
 
 
-def anonymize_formula(formula: str, sheet_index: int, steps_manager: StepsManager=None) -> str:
+def anonymize_formula(formula: str, sheet_index: int, steps_manager: StepsManagerType=None) -> str:
     """
     Helper function that anonymizes formula to 
     make sure that no private data is included in it.
@@ -154,7 +166,10 @@ def get_installed_mitosheets_pip_show():
         return []
 
 
-def log(log_event: str, params: Dict[Any, Any]=None, steps_manager: StepsManager=None) -> None:
+# We only calculate the location once so that we don't cause performance issues
+location = None
+
+def log(log_event: str, params: Dict[Any, Any]=None, steps_manager: StepsManagerType=None) -> None:
     """
     Helper function that logs an event with the given parameters. However,
     this function is also responsible for making sure _zero_ private data
@@ -167,13 +182,24 @@ def log(log_event: str, params: Dict[Any, Any]=None, steps_manager: StepsManager
 
     if params is None:
         params = {}
+
+    global location
+    if location is None:
+        location = get_location()
     
     # Add the python properties to every log event we can
     python_properties = {
         'version_python': sys.version_info,
         'version_jupyterlab': jupyterlab_version,
-        'version_mito': __version__ 
+        'version_notebook': notebook_version,
+        'version_mito': __version__,
+        'package_name': package_name,
+        'location': location,
+        'is_docker': is_docker()
     }
+
+    # Add some data about where this is being run from, so we make sure we
+    # support users systems
     
     params = dict(
         **params,
@@ -229,9 +255,15 @@ def log(log_event: str, params: Dict[Any, Any]=None, steps_manager: StepsManager
                     private_params[key] = len(value)
                 else:
                     private_params[key] = value
+            elif 'graph_creation' in key:
+                # Don't log the column ids in the graph, just log the number of series graphed
+                private_params['params_x_axis_column_ids'] = len(value['x_axis_column_ids'])
+                private_params['params_y_axis_column_ids'] = len(value['y_axis_column_ids'])
+                private_params['params_color'] = True if 'color' in value.keys() else False
             elif 'sheet_index' in key:
                 private_params[key] = value
-                if steps_manager:
+                # Make sure the steps manager exists, and the source is in bounds
+                if steps_manager and len(steps_manager.curr_step.df_sources) > value:
                     private_params[key + '_df_source'] = steps_manager.curr_step.df_sources[value]
             else:
                 private_params[key] = value
@@ -281,7 +313,9 @@ def identify() -> None:
             'version_python': sys.version_info,
             'version_sys': sys.version,
             'version_mito': __version__,
+            'package_name': package_name, 
             'version_jupyterlab': jupyterlab_version,
+            'version_notebook': notebook_version,
             'operating_system': operating_system,
             'email': user_email,
             'local': local,
@@ -314,7 +348,7 @@ def log_recent_error(log_event: str=None) -> None:
     )
 
 
-def log_event_processed(event: Dict[str, Any], steps_manager: StepsManager, failed: bool=False, mito_error: MitoError=None) -> None:
+def log_event_processed(event: Dict[str, Any], steps_manager: StepsManagerType, failed: bool=False, mito_error: MitoError=None, start_time: float=None) -> None:
     """
     Helper function for logging when an event is processed
     by the widget state container. 
@@ -397,9 +431,36 @@ def log_event_processed(event: Dict[str, Any], steps_manager: StepsManager, fail
         else:
             error_properties = {}
 
+        # We also log some timing information - which we round to a single decimal place just
+        # so that we can bucket these items easily. Note we include a variety of roundings of 
+        # the time, so that we can make sure to aggregate in Mixpanel well (which will die if 
+        # it is given to many values).
+        if start_time is not None:
+            processing_time = time.perf_counter() - start_time
+            event_properties['processing_time'] = round(processing_time, 1)
+            event_properties['processing_time_seconds'] = int(round(processing_time, 0))
+            event_properties['processing_time_seconds_ten'] = int(round(processing_time, -1))
+            event_properties['processing_time_seconds_hundred'] = int(round(processing_time, -2))
+
+            # If we just did an update, and this update has a pandas processing time, then we can calculate the
+            # time that we spent as mito overhead vs. just 
+            if steps_manager and steps_manager.curr_step.execution_data and 'pandas_processing_time' in steps_manager.curr_step.execution_data:
+                pandas_processing_time = steps_manager.curr_step.execution_data['pandas_processing_time']
+                event_properties['processing_time_pandas'] = round(pandas_processing_time, 1)
+                event_properties['processing_time_pandas_seconds'] = int(round(pandas_processing_time, 0))
+                event_properties['processing_time_pandas_seconds_ten'] = int(round(pandas_processing_time, -1))
+                event_properties['processing_time_pandas_seconds_hundred'] = int(round(pandas_processing_time, -2))
+
+                # And we explicitly calculate the overhead
+                overhead_processing_time = round(processing_time - pandas_processing_time, 1)
+                event_properties['processing_time_overhead'] = overhead_processing_time
+                event_properties['processing_time_overhead_seconds'] = int(round(overhead_processing_time, 0))
+                event_properties['processing_time_overhead_seconds_ten'] = int(round(overhead_processing_time, -1))
+                event_properties['processing_time_overhead_seconds_hundred'] = int(round(overhead_processing_time, -2))
+
         # We choose to log the event type, as it is the best high-level item for our logs
         # and we append a _failed if the event failed in doing this.
-        log_event = event['type'] + ('_failed' if failed else '')
+        log_event: str = event['type'] + ('_failed' if failed else '')
 
         log(
             log_event, 
@@ -410,6 +471,59 @@ def log_event_processed(event: Dict[str, Any], steps_manager: StepsManager, fail
             ),
             steps_manager=steps_manager
         )
+
+        if failed:
+            # We also generate a double log in the case of errors, whenever anything fails. This allows
+            # us to easily track the number of users who are getting errors
+            log(
+                'error', 
+                dict(
+                    log_event=log_event,
+                    **event_properties,
+                    **steps_manager_properties,
+                    **error_properties
+                ),
+                steps_manager=steps_manager
+            )
+        else:
+            # We also generate a single aggregate log for each of the different
+            # types of events the user sends to the backend. As with the above, 
+            # this allows us to easily aggregate across different types of events
+            # and track general trends (at the cost of making the logs look a bit
+            # messier to human eyes)
+            if event['event'] == 'edit_event':
+                log(
+                    'edit_event', 
+                    dict(
+                        log_event=log_event,
+                        **event_properties,
+                        **steps_manager_properties,
+                        **error_properties
+                    ),
+                    steps_manager=steps_manager
+                )
+            elif event['event'] == 'update_event':
+                log(
+                    'update_event', 
+                    dict(
+                        log_event=log_event,
+                        **event_properties,
+                        **steps_manager_properties,
+                        **error_properties
+                    ),
+                    steps_manager=steps_manager
+                )
+            elif event['event'] == 'api_call':
+                log(
+                    'api_call', 
+                    dict(
+                        log_event=log_event,
+                        **event_properties,
+                        **steps_manager_properties,
+                        **error_properties
+                    ),
+                    steps_manager=steps_manager
+                )
     except:
         # We don't want logging to ever brick the application, so if the logging fails
         # we just log simple information about the event. This should never occur, but it
