@@ -1,9 +1,8 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# Copyright (c) Mito.
-# Distributed under the terms of the Modified BSD License.
-
+# Copyright (c) Saga Inc.
+# Distributed under the terms of the GPL License.
 """
 See mito/mitosheet/steps/README.md for more information about 
 how to add a step!
@@ -30,6 +29,11 @@ from mitosheet.step_performers.dataframe_steps.dataframe_delete import Dataframe
 from mitosheet.step_performers.dataframe_steps.dataframe_duplicate import DataframeDuplicateStepPerformer
 from mitosheet.step_performers.dataframe_steps.dataframe_rename import DataframeRenameStepPerformer
 from mitosheet.step_performers.bulk_old_rename.bulk_old_rename import BulkOldRenameStepPerformer
+from mitosheet.step_performers.graph_steps.graph import GraphStepPerformer
+from mitosheet.step_performers.graph_steps.graph_delete import GraphDeleteStepPerformer
+from mitosheet.step_performers.graph_steps.graph_duplicate import GraphDuplicateStepPerformer
+from mitosheet.step_performers.graph_steps.graph_rename import GraphRenameStepPerformer
+
 
 # All steps must be listed in this variable. Note the Type annotation allows for
 # subtypes of the step performer to be passed
@@ -52,7 +56,11 @@ STEP_PERFORMERS: List[Type[StepPerformer]] = [
     DataframeDuplicateStepPerformer,
     DataframeRenameStepPerformer,
     BulkOldRenameStepPerformer,
-    DropDuplicatesStepPerformer
+    DropDuplicatesStepPerformer,
+    GraphStepPerformer,
+    GraphDeleteStepPerformer,
+    GraphDuplicateStepPerformer,
+    GraphRenameStepPerformer
 ]
 
 # A helpful mapping for looking up steps based on the incoming events
