@@ -1,10 +1,12 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# Copyright (c) Mito.
+# Copyright (c) Saga Inc.
+# Distributed under the terms of the GPL License.
 
 from copy import deepcopy
 import functools
+from time import perf_counter
 from typing import Any, Dict, List, Optional, Set, Tuple, Union
 import pandas as pd
 from datetime import date
@@ -30,6 +32,8 @@ FC_STRING_CONTAINS = "contains"
 FC_STRING_DOES_NOT_CONTAIN = "string_does_not_contain"
 FC_STRING_EXACTLY = "string_exactly"
 FC_STRING_NOT_EXACTLY = "string_not_exactly"
+FC_STRING_STARTS_WITH = "string_starts_with"
+FC_STRING_ENDS_WITH = "string_ends_with"
 
 FC_NUMBER_EXACTLY = "number_exactly"
 FC_NUMBER_NOT_EXACTLY = "number_not_exactly"
@@ -65,6 +69,8 @@ FILTER_FORMAT_STRING_DICT = {
     FC_STRING_DOES_NOT_CONTAIN: "~{df_name}[{transpiled_column_header}].str.contains('{value}', na=False)",
     FC_STRING_EXACTLY: "{df_name}[{transpiled_column_header}] == '{value}'",
     FC_STRING_NOT_EXACTLY: "{df_name}[{transpiled_column_header}] != '{value}'",
+    FC_STRING_STARTS_WITH: "{df_name}[{transpiled_column_header}].str.startswith('{value}', na=False)",
+    FC_STRING_ENDS_WITH: "{df_name}[{transpiled_column_header}].str.endswith('{value}', na=False)",
     # DATES
     FC_DATETIME_EXACTLY: "{df_name}[{transpiled_column_header}] == pd.to_datetime('{value}')",
     FC_DATETIME_NOT_EXACTLY: "{df_name}[{transpiled_column_header}] != pd.to_datetime('{value}')",
@@ -133,6 +139,14 @@ FILTER_FORMAT_STRING_MULTIPLE_VALUES_DICT = {
         "Or": "{df_name}[{transpiled_column_header}].apply(lambda val: any(val != s for s in {values}))",
         "And": "{df_name}[{transpiled_column_header}].apply(lambda val: all(val != s for s in {values}))",
     },
+    FC_STRING_STARTS_WITH: {
+        "Or": "{df_name}[{transpiled_column_header}].apply(lambda val: any(str(val).startswith(s) for s in {values}))",
+        "And": "{df_name}[{transpiled_column_header}].apply(lambda val: all(str(val).startswith(s) for s in {values}))",
+    },
+    FC_STRING_ENDS_WITH: {
+        "Or": "{df_name}[{transpiled_column_header}].apply(lambda val: any(str(val).endswith(s) for s in {values}))",
+        "And": "{df_name}[{transpiled_column_header}].apply(lambda val: all(str(val).endswith(s) for s in {values}))",
+    },
     FC_DATETIME_EXACTLY: {
         "Or": "{df_name}[{transpiled_column_header}].isin({values})",
         "And": "{df_name}[{transpiled_column_header}].apply(lambda val: all(val == d for d in {values}))",
@@ -224,15 +238,18 @@ class FilterStepPerformer(StepPerformer):
         post_state = deepcopy(prev_state)
 
         # Execute the filter
-        post_state.dfs[sheet_index] = _execute_filter(
+        final_df, pandas_processing_time = _execute_filter(
             prev_state.dfs[sheet_index], column_header, operator, filters
         )
+        post_state.dfs[sheet_index] = final_df
 
         # Keep track of which columns are filtered
         post_state.column_filters[sheet_index][column_id]["operator"] = operator
         post_state.column_filters[sheet_index][column_id]["filters"] = filters
 
-        return post_state, None
+        return post_state, {
+            'pandas_processing_time': pandas_processing_time
+        }
 
     @classmethod
     def transpile(  # type: ignore
@@ -365,8 +382,12 @@ def get_applied_filter(
     # Then string
     if condition == FC_STRING_CONTAINS:
         return df[column_header].str.contains(value, na=False)
-    if condition == FC_STRING_DOES_NOT_CONTAIN:
+    elif condition == FC_STRING_DOES_NOT_CONTAIN:
         return ~df[column_header].str.contains(value, na=False)
+    elif condition == FC_STRING_STARTS_WITH:
+        return df[column_header].str.startswith(value, na=False)
+    elif condition == FC_STRING_ENDS_WITH:
+        return df[column_header].str.endswith(value, na=False)
     elif condition == FC_STRING_EXACTLY:
         return df[column_header] == value
     elif condition == FC_STRING_NOT_EXACTLY:
@@ -430,13 +451,14 @@ def _execute_filter(
     column_header: ColumnHeader,
     operator: str,
     filters: List[Dict[str, Any]],
-) -> pd.DataFrame:
+) -> Tuple[pd.DataFrame, float]:
     """
     Executes a filter on the given column, filtering by removing any rows who
     don't meet the condition.
     """
 
     applied_filters = []
+    pandas_start_time = perf_counter()
 
     for filter_or_group in filters:
 
@@ -458,10 +480,15 @@ def _execute_filter(
                 get_applied_filter(df, column_header, filter_or_group)
             )
 
+    
     if len(applied_filters) > 0:
-        return df[combine_filters(operator, applied_filters)]
+        filtered_df = df[combine_filters(operator, applied_filters)]
     else:
-        return df
+        filtered_df = df
+
+    pandas_processing_time = perf_counter() - pandas_start_time
+
+    return filtered_df, pandas_processing_time
 
 
 def get_single_filter_string(
