@@ -8,8 +8,6 @@ from copy import deepcopy
 from time import perf_counter
 from typing import Any, Dict, List, Optional, Set, Tuple
 import pandas as pd
-from mitosheet.code_chunks.code_chunk import CodeChunk
-from mitosheet.code_chunks.empty_code_chunk import EmptyCodeChunk
 
 from mitosheet.state import State
 from mitosheet.step_performers.graph_steps.graph_utils import GRAPH_TITLE_LABELS, get_html_and_script_from_figure, get_new_graph_tab_name
@@ -18,7 +16,6 @@ from mitosheet.step_performers.graph_steps.plotly_express_graphs import (
     get_plotly_express_graph_code,
 )
 from mitosheet.step_performers.step_performer import StepPerformer
-from mitosheet.step_performers.utils import get_param
 from mitosheet.types import GraphID
 
 
@@ -38,24 +35,7 @@ class GraphStepPerformer(StepPerformer):
             y_axis_column_ids: ColumnID[],
             color: columnID: columnID
         },
-        graph_styling: {
-            title: {
-                title: string | None
-                visible: boolean
-            },
-            xaxis: {
-                title: string | None,
-                visible: boolean,
-                rangeslider: {
-                    visible: boolean
-                }
-            },
-            yaxis: {
-                title: string | None,
-                visible: boolean
-            },
-            showlegend: boolean
-        },
+        graph_styling: {},
         graph_rendering: {
             height: int representing the div width
             width: int representing the div width
@@ -65,29 +45,41 @@ class GraphStepPerformer(StepPerformer):
 
     @classmethod
     def step_version(cls) -> int:
-        return 3
+        return 1
 
     @classmethod
     def step_type(cls) -> str:
         return "graph"
 
+    @classmethod
+    def step_display_name(cls) -> str:
+        return "Created a graph"
+
+    @classmethod
+    def step_event_type(cls) -> str:
+        return "graph_edit"
+
     @classmethod
     def saturate(cls, prev_state: State, params: Dict[str, Any]) -> Dict[str, Any]:
         return params
 
     @classmethod
-    def execute(cls, prev_state: State, params: Dict[str, Any]) -> Tuple[State, Optional[Dict[str, Any]]]:
+    def execute(  # type: ignore
+        cls,
+        prev_state: State,
+        graph_id: GraphID,
+        graph_preprocessing: Dict[str, Any],
+        graph_creation: Dict[str, Any],
+        graph_styling: Dict[str, Any],
+        graph_rendering: Dict[str, Any],
+        **params,
+    ) -> Tuple[State, Optional[Dict[str, Any]]]:
         """
         Returns the new post state with the updated graph_data_dict
         """
-        graph_id: GraphID = get_param(params, 'graph_id')
-        graph_preprocessing: Dict[str, Any] = get_param(params, 'graph_preprocessing')
-        graph_creation: Dict[str, Any] = get_param(params, 'graph_creation')
-        graph_styling: Dict[str, Any] = get_param(params, 'graph_styling')
-        graph_rendering: Dict[str, Any] = get_param(params, 'graph_rendering')
 
         # We make a new state to modify it
-        post_state = prev_state.copy()
+        post_state = deepcopy(prev_state)
 
         # Extract variables from graph parameters
         graph_type = graph_creation["graph_type"]
@@ -136,8 +128,7 @@ class GraphStepPerformer(StepPerformer):
                 safety_filter_turned_on_by_user,
                 x_axis_column_headers,
                 y_axis_column_headers,
-                color_column_header,
-                graph_styling
+                color_column_header
             )
             pandas_processing_time = perf_counter() - pandas_start_time
 
@@ -160,7 +151,6 @@ class GraphStepPerformer(StepPerformer):
                 x_axis_column_headers,
                 y_axis_column_headers,
                 color_column_header,
-                graph_styling,
                 df_name,
             )
 
@@ -184,25 +174,39 @@ class GraphStepPerformer(StepPerformer):
         }
 
     @classmethod
-    def transpile(
+    def transpile(  # type: ignore
         cls,
         prev_state: State,
         post_state: State,
-        params: Dict[str, Any],
         execution_data: Optional[Dict[str, Any]],
-    ) -> List[CodeChunk]:
+        graph_preprocessing: Dict[str, Any],
+        graph_creation: Dict[str, Any],
+        graph_styling: Dict[str, Any],
+        graph_rendering: Dict[str, Any],
+        **params,
+    ) -> List[str]:
         # Graph steps don't add any generated code to the analysis script. 
-        return [
-            EmptyCodeChunk(
-                prev_state, 
-                post_state, 
-                {
-                    'display_name': 'Edited graph',
-                    'description_comment': 'Edited a graph',
-                },
-                execution_data
-            )
-        ]
+        # Instead, the graph code is created during execution of the function and is
+        # retuned to the frontend through the graph_data_dict object so that the user can copy 
+        # and paste it. 
+        return []
+
+    @classmethod
+    def describe(  # type: ignore
+        cls,
+        graph_preprocessing: Any,
+        graph_creation: Any,
+        graph_styling: Any,
+        graph_rendering: Any,
+        df_names=None,
+        **params,
+    ) -> str:
+        sheet_index = graph_creation["sheet_index"]
+        graph_type = graph_creation["graph_type"]
+        if df_names is not None:
+            df_name = df_names[sheet_index]
+            return f"Graphed {df_name} as {GRAPH_TITLE_LABELS[graph_type]}"
+        return f"Created {GRAPH_TITLE_LABELS[graph_type]}"
 
     @classmethod
     def get_modified_dataframe_indexes(cls, graph_creation, **params) -> Set[int]:  # type: ignore
