@@ -28,6 +28,10 @@ class GraphDuplicateStepPerformer(StepPerformer):
     @classmethod
     def step_display_name(cls) -> str:
         return 'Duplicated a Graph'
+    
+    @classmethod
+    def step_event_type(cls) -> str:
+        return 'graph_duplicate_edit'
 
     @classmethod
     def saturate(cls, prev_state: State, params: Dict[str, Any]) -> Dict[str, Any]:
@@ -41,7 +45,7 @@ class GraphDuplicateStepPerformer(StepPerformer):
         new_graph_id: GraphID,
         **params
     ) -> Tuple[State, Optional[Dict[str, Any]]]:
-        post_state = prev_state.copy()
+        post_state = deepcopy(prev_state)
 
         # Execute the step
         graph_copy = deepcopy(post_state.graph_data_dict[old_graph_id])
