@@ -1,10 +1,10 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# Copyright (c) Mito.
-# Distributed under the terms of the Modified BSD License.
-
+# Copyright (c) Saga Inc.
+# Distributed under the terms of the GPL License.
 from copy import copy
+from time import perf_counter
 from typing import Any, Dict, List, Optional, Set, Tuple
 import pandas as pd
 
@@ -61,7 +61,9 @@ class ExcelImportStepPerformer(StepPerformer):
         if not has_headers:
             read_excel_params['header'] = None
 
-        df_dictonary = pd.read_excel(file_name, **read_excel_params) 
+        pandas_start_time = perf_counter()
+        df_dictonary = pd.read_excel(file_name, **read_excel_params, engine='openpyxl') 
+        pandas_processing_time = perf_counter() - pandas_start_time
 
         for sheet_name, df in df_dictonary.items():
             post_state.add_df_to_state(
@@ -70,7 +72,9 @@ class ExcelImportStepPerformer(StepPerformer):
                 df_name=get_valid_dataframe_name(post_state.df_names, sheet_name),
             )
 
-        return post_state, {}
+        return post_state, {
+            'pandas_processing_time': pandas_processing_time
+        }
 
 
     @classmethod
@@ -95,7 +99,7 @@ class ExcelImportStepPerformer(StepPerformer):
         if not has_headers:
             read_excel_params['header'] = None
 
-        read_excel_line = f'sheet_df_dictonary = pd.read_excel(\'{file_name}\''
+        read_excel_line = f'sheet_df_dictonary = pd.read_excel(\'{file_name}\', engine=\'openpyxl\''
         for key, value in read_excel_params.items():
             read_excel_line += f', {key}={value}'
         read_excel_line += ')'
